Geliştiriciler

Geliştiriciler için API Referansı

İsteklerin sistem tarafından işlenmesi için bir API anahtarı gereklidir. Bir kullanıcı kayıt olduğunda bu kullanıcı için otomatik olarak bir API anahtarı oluşturulur.

Başlangıç

İsteklerin sistem tarafından işlenmesi için bir API anahtarı gereklidir. Bir kullanıcı kayıt olduğunda bu kullanıcı için otomatik olarak bir API anahtarı oluşturulur. API anahtarı her istekle birlikte gönderilmelidir (aşağıdaki tam örneğe bakın). API anahtarı gönderilmezse veya süresi dolmuşsa hata oluşur. Kötüye kullanımı önlemek için lütfen API anahtarınızı gizli tutun.

Kimlik Doğrulama

API sistemiyle kimlik doğrulamak için API anahtarınızı her istekle birlikte yetkilendirme belirteci olarak göndermeniz gerekir. Örnek kodu aşağıda görebilirsiniz.

curl --location --request POST 'https://tiklagit.ac/api/account' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \ 

Hız Sınırı

API'miz, kararlılığını en üst düzeye çıkarmak amacıyla ani istek artışlarına karşı koruma sağlayan bir hız sınırlayıcıya sahiptir. Hız sınırlayıcımız şu anda 1 dakikada 30 istekle sınırlıdır. Lütfen bu sınırın abone olunan plana göre değişebileceğini unutmayın.

Yanıtla birlikte birkaç üst bilgi gönderilir ve istek hakkında çeşitli bilgileri belirlemek için bunlar incelenebilir.

X-RateLimit-Limit: 30X-RateLimit-Remaining: 29X-RateLimit-Reset: TIMESTAMP

Yanıt İşleme

Tüm API yanıtları varsayılan olarak JSON biçiminde döndürülür. Bunu kullanılabilir veriye dönüştürmek için dile uygun işlevin kullanılması gerekir. PHP'de json_decode() işlevi, veriyi bir nesneye (varsayılan) veya bir diziye (ikinci parametreyi true olarak ayarlayın) dönüştürmek için kullanılabilir. Bir hata olup olmadığına dair bilgi sağladığı için error anahtarını kontrol etmek çok önemlidir. Ayrıca üst bilgi kodunu da kontrol edebilirsiniz.

{
    "error": 1,
    "message": "An error occurred"
}

CTA Katmanları

CTA Katmanlarını Listele

GET https://tiklagit.ac/api/overlay?limit=2&page=1

CTA katmanlarını API üzerinden almak için bu uç noktayı kullanabilirsiniz. Verileri filtreleyebilirsiniz de (Daha fazla bilgi için tabloya bakın).

Parametre Açıklama
limit (isteğe bağlı) Sayfa başına veri sonucu
page (isteğe bağlı) İstenen geçerli sayfa
curl --location --request GET 'https://tiklagit.ac/api/overlay?limit=2&page=1' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \

Sunucu yanıtı

{
    "error": "0",
    "data": {
        "result": 2,
        "perpage": 2,
        "currentpage": 1,
        "nextpage": 1,
        "maxpage": 1,
        "cta": [
            {
                "id": 1,
                "type": "message",
                "name": "Product 1 Promo",
                "date": "2020-11-10 18:00:00"
            },
            {
                "id": 2,
                "type": "contact",
                "name": "Contact Page",
                "date": "2020-11-10 18:10:00"
            }
        ]
    }
}

Hesap

Hesabı Getir

GET https://tiklagit.ac/api/account

Hesap hakkında bilgi almak için bu uç noktaya bir istek gönderebilirsiniz; uç nokta hesaba ait verileri döndürür.

curl --location --request GET 'https://tiklagit.ac/api/account' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \

Sunucu yanıtı

{
    "error": 0,
    "data": {
        "id": 1,
        "email": "sample@domain.com",
        "username": "sampleuser",
        "avatar": "https:\/\/domain.com\/content\/avatar.png",
        "status": "pro",
        "expires": "2022-11-15 15:00:00",
        "registered": "2020-11-10 18:01:43"
    }
}

Hesabı Güncelle

PUT https://tiklagit.ac/api/account/update

Hesap bilgilerini güncellemek için bu uç noktaya bir istek gönderebilirsiniz; uç nokta hesaba ait verileri günceller.

curl --location --request PUT 'https://tiklagit.ac/api/account/update' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \
--data-raw '{
    "email": "newemail@google.com",
    "password": "NewPassword1"
}'

Sunucu yanıtı

{
    "error": 0,
    "message": "Account has been successfully updated."
}

Kampanyalar

Kampanyaları Listele

GET https://tiklagit.ac/api/campaigns?limit=2&page=1

Kampanyalarınızı API üzerinden almak için bu uç noktayı kullanabilirsiniz. Ayrıca verileri filtreleyebilirsiniz (Daha fazla bilgi için tabloya bakın).

Parametre Açıklama
limit (isteğe bağlı) Sayfa başına veri sonucu
page (isteğe bağlı) İstenen geçerli sayfa
curl --location --request GET 'https://tiklagit.ac/api/campaigns?limit=2&page=1' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \

Sunucu yanıtı

{
    "error": "0",
    "data": {
        "result": 2,
        "perpage": 2,
        "currentpage": 1,
        "nextpage": 1,
        "maxpage": 1,
        "campaigns": [
            {
                "id": 1,
                "name": "Sample Campaign",
                "public": false,
                "rotator": false,
                "list": "https:\/\/domain.com\/u\/admin\/list-1"
            },
            {
                "id": 2,
                "domain": "Facebook Campaign",
                "public": true,
                "rotator": "https:\/\/domain.com\/r\/test",
                "list": "https:\/\/domain.com\/u\/admin\/test-2"
            }
        ]
    }
}

Kampanya Oluştur

POST https://tiklagit.ac/api/campaign/add

Bu uç nokta kullanılarak bir kampanya eklenebilir.

Parametre Açıklama
name (isteğe bağlı) Kampanya adı
slug (isteğe bağlı) Rotator slug'ı
public (isteğe bağlı) Erişim
curl --location --request POST 'https://tiklagit.ac/api/campaign/add' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \
--data-raw '{
    "name": "New Campaign",
    "slug": "new-campaign",
    "public": true
}'

Sunucu yanıtı

{
    "error": 0,
    "id": 3,
    "domain": "New Campaign",
    "public": true,
    "rotator": "https:\/\/domain.com\/r\/new-campaign",
    "list": "https:\/\/domain.com\/u\/admin\/new-campaign-3"
}

Bir Bağlantıyı Kampanyaya Ata

POST https://tiklagit.ac/api/campaign/:campaignid/assign/:linkid

Bu uç nokta kullanılarak bir kısa bağlantı bir kampanyaya atanabilir. Uç nokta, kampanya ID'sini ve kısa bağlantı ID'sini gerektirir.

curl --location --request POST 'https://tiklagit.ac/api/campaign/:campaignid/assign/:linkid' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \

Sunucu yanıtı

{
    "error": 0,
    "message": "Link successfully added to the campaign."
}

Kampanyayı Güncelle

PUT https://tiklagit.ac/api/campaign/:id/update

Bir kampanyayı güncellemek için PUT isteğiyle geçerli bir JSON verisi göndermeniz gerekir. Veriler, aşağıda gösterildiği gibi isteğinizin ham gövdesi olarak gönderilmelidir. Aşağıdaki örnek gönderebileceğiniz tüm parametreleri göstermektedir ancak hepsini göndermeniz zorunlu değildir (Daha fazla bilgi için tabloya bakın).

Parametre Açıklama
name (zorunlu) Kampanya adı
slug (isteğe bağlı) Rotator slug'ı
public (isteğe bağlı) Erişim
curl --location --request PUT 'https://tiklagit.ac/api/campaign/:id/update' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \
--data-raw '{
    "name": "Twitter Campaign",
    "slug": "twitter-campaign",
    "public": true
}'

Sunucu yanıtı

{
    "error": 0,
    "id": 3,
    "domain": "Twitter Campaign",
    "public": true,
    "rotator": "https:\/\/domain.com\/r\/twitter-campaign",
    "list": "https:\/\/domain.com\/u\/admin\/twitter-campaign-3"
}

Kampanyayı Sil

DELETE https://tiklagit.ac/api/campaign/:id/delete

Bir kampanyayı silmek için DELETE isteği göndermeniz gerekir.

curl --location --request DELETE 'https://tiklagit.ac/api/campaign/:id/delete' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \

Sunucu yanıtı

{
    "error": 0,
    "message": "Campaign has been deleted successfully."
}

Kanallar

Kanalları Listele

GET https://tiklagit.ac/api/channels?limit=2&page=1

Kanallarınızı API üzerinden almak için bu uç noktayı kullanabilirsiniz. Ayrıca verileri filtreleyebilirsiniz (Daha fazla bilgi için tabloya bakın).

Parametre Açıklama
limit (isteğe bağlı) Sayfa başına veri sonucu
page (isteğe bağlı) İstenen geçerli sayfa
curl --location --request GET 'https://tiklagit.ac/api/channels?limit=2&page=1' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \

Sunucu yanıtı

{
    "error": "0",
    "data": {
        "result": 2,
        "perpage": 2,
        "currentpage": 1,
        "nextpage": 1,
        "maxpage": 1,
        "channels": [
            {
                "id": 1,
                "name": "Channel 1",
                "description": "Description of channel 1",
                "color": "#000000",
                "starred": true
            },
            {
                "id": 2,
                "name": "Channel 2",
                "description": "Description of channel 2",
                "color": "#FF0000",
                "starred": false
            }
        ]
    }
}

Kanal Öğelerini Listele

GET https://tiklagit.ac/api/channel/:id?limit=1&page=1

Seçili bir kanaldaki öğeleri API üzerinden almak için bu uç noktayı kullanabilirsiniz. Ayrıca verileri filtreleyebilirsiniz (Daha fazla bilgi için tabloya bakın).

Parametre Açıklama
limit (isteğe bağlı) Sayfa başına veri sonucu
page (isteğe bağlı) İstenen geçerli sayfa
curl --location --request GET 'https://tiklagit.ac/api/channel/:id?limit=1&page=1' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \

Sunucu yanıtı

{
    "error": "0",
    "data": {
        "result": 2,
        "perpage": 2,
        "currentpage": 1,
        "nextpage": 1,
        "maxpage": 1,
        "items": [
            {
                "type": "links",
                "id": 1,
                "title": "My Sample Link",
                "preview": "https:\/\/google.com",
                "link": "https:\/\/tiklagit.ac\/google",
                "date": "2022-05-12"
            },
            {
                "type": "bio",
                "id": 1,
                "title": "My Sample Bio",
                "preview": "https:\/\/tiklagit.ac\/mybio",
                "link": "https:\/\/tiklagit.ac\/mybio",
                "date": "2022-06-01"
            }
        ]
    }
}

Kanal Oluştur

POST https://tiklagit.ac/api/channel/add

Bu uç nokta kullanılarak bir kanal eklenebilir.

Parametre Açıklama
name (zorunlu) Kanal adı
description (isteğe bağlı) Kanal açıklaması
color (isteğe bağlı) Kanal rozet rengi (HEX)
starred (isteğe bağlı) Kanalın yıldızlanıp yıldızlanmayacağı (true veya false)
curl --location --request POST 'https://tiklagit.ac/api/channel/add' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \
--data-raw '{
    "name": "New Channel",
    "description": "my new channel",
    "color": "#000000",
    "starred": true
}'

Sunucu yanıtı

{
    "error": 0,
    "id": 3,
    "name": "New Channel",
    "description": "my new channel",
    "color": "#000000",
    "starred": true
}

Bir Öğeyi Kanala Ata

POST https://tiklagit.ac/api/channel/:channelid/assign/:type/:itemid

Kanal ID'si, öğe türü (links, bio veya qr) ve öğe ID'si ile bir istek gönderilerek herhangi bir kanala bir öğe atanabilir.

Parametre Açıklama
:channelid (zorunlu) Kanal ID'si
:type (zorunlu) links, bio veya qr
:itemid (zorunlu) Öğe ID'si
curl --location --request POST 'https://tiklagit.ac/api/channel/:channelid/assign/:type/:itemid' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \

Sunucu yanıtı

{
    "error": 0,
    "message": "Item successfully added to the channel."
}

Kanalı Güncelle

PUT https://tiklagit.ac/api/channel/:id/update

Bir kanalı güncellemek için PUT isteğiyle geçerli bir JSON verisi göndermeniz gerekir. Veriler, aşağıda gösterildiği gibi isteğinizin ham gövdesi olarak gönderilmelidir. Aşağıdaki örnek gönderebileceğiniz tüm parametreleri göstermektedir ancak hepsini göndermeniz zorunlu değildir (Daha fazla bilgi için tabloya bakın).

Parametre Açıklama
name (isteğe bağlı) Kanal adı
description (isteğe bağlı) Kanal açıklaması
color (isteğe bağlı) Kanal rozet rengi (HEX)
starred (isteğe bağlı) Kanalın yıldızlanıp yıldızlanmayacağı (true veya false)
curl --location --request PUT 'https://tiklagit.ac/api/channel/:id/update' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \
--data-raw '{
    "name": "Acme Corp",
    "description": "channel for items for Acme Corp",
    "color": "#FFFFFF",
    "starred": false
}'

Sunucu yanıtı

{
    "error": 0,
    "message": "Channel has been updated successfully."
}

Kanalı Sil

DELETE https://tiklagit.ac/api/channel/:id/delete

Bir kanalı silmek için DELETE isteği göndermeniz gerekir. Tüm öğelerin atamaları da kaldırılır.

curl --location --request DELETE 'https://tiklagit.ac/api/channel/:id/delete' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \

Sunucu yanıtı

{
    "error": 0,
    "message": "Channel has been deleted successfully."
}

Markalı Alan Adları

Markalı Alan Adlarını Listele

GET https://tiklagit.ac/api/domains?limit=2&page=1

Markalı alan adlarınızı API üzerinden almak için bu uç noktayı kullanabilirsiniz. Ayrıca verileri filtreleyebilirsiniz (Daha fazla bilgi için tabloya bakın).

Parametre Açıklama
limit (isteğe bağlı) Sayfa başına veri sonucu
page (isteğe bağlı) İstenen geçerli sayfa
curl --location --request GET 'https://tiklagit.ac/api/domains?limit=2&page=1' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \

Sunucu yanıtı

{
    "error": "0",
    "data": {
        "result": 2,
        "perpage": 2,
        "currentpage": 1,
        "nextpage": 1,
        "maxpage": 1,
        "domains": [
            {
                "id": 1,
                "domain": "https:\/\/domain1.com",
                "redirectroot": "https:\/\/rootdomain.com",
                "redirect404": "https:\/\/rootdomain.com\/404"
            },
            {
                "id": 2,
                "domain": "https:\/\/domain2.com",
                "redirectroot": "https:\/\/rootdomain2.com",
                "redirect404": "https:\/\/rootdomain2.com\/404"
            }
        ]
    }
}

Markalı Alan Adı Oluştur

POST https://tiklagit.ac/api/domain/add

Bu uç nokta kullanılarak bir alan adı eklenebilir. Lütfen alan adının sunucumuza doğru şekilde yönlendirildiğinden emin olun.

Parametre Açıklama
domain (zorunlu) http veya https dahil markalı alan adı
redirectroot (isteğe bağlı) Alan adınız ziyaret edildiğinde uygulanacak kök yönlendirme
redirect404 (isteğe bağlı) Özel 404 yönlendirmesi
curl --location --request POST 'https://tiklagit.ac/api/domain/add' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \
--data-raw '{
    "domain": "https:\/\/domain1.com",
    "redirectroot": "https:\/\/rootdomain.com",
    "redirect404": "https:\/\/rootdomain.com\/404"
}'

Sunucu yanıtı

{
    "error": 0,
    "id": 1
}

Alan Adını Güncelle

PUT https://tiklagit.ac/api/domain/:id/update

Markalı bir alan adını güncellemek için PUT isteğiyle JSON biçiminde geçerli veri göndermeniz gerekir. Veriler, aşağıda gösterildiği gibi isteğinizin ham gövdesi olarak gönderilmelidir. Aşağıdaki örnek gönderebileceğiniz tüm parametreleri gösterir ancak hepsini göndermeniz zorunlu değildir (Daha fazla bilgi için tabloya bakın).

Parametre Açıklama
redirectroot (isteğe bağlı) Alan adınız ziyaret edildiğinde uygulanacak kök yönlendirme
redirect404 (isteğe bağlı) Özel 404 yönlendirmesi
curl --location --request PUT 'https://tiklagit.ac/api/domain/:id/update' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \
--data-raw '{
    "redirectroot": "https:\/\/rootdomain-new.com",
    "redirect404": "https:\/\/rootdomain-new.com\/404"
}'

Sunucu yanıtı

{
    "error": 0,
    "message": "Domain has been updated successfully."
}

Alan Adını Sil

DELETE https://tiklagit.ac/api/domain/:id/delete

Bir alan adını silmek için DELETE isteği göndermeniz gerekir.

curl --location --request DELETE 'https://tiklagit.ac/api/domain/:id/delete' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \

Sunucu yanıtı

{
    "error": 0,
    "message": "Domain has been deleted successfully."
}

Pikseller

Pikselleri Listele

GET https://tiklagit.ac/api/pixels?limit=2&page=1

Piksel kodlarınızı API üzerinden almak için bu uç noktayı kullanabilirsiniz. Verileri filtreleyebilirsiniz de (Daha fazla bilgi için tabloya bakın).

Parametre Açıklama
limit (isteğe bağlı) Sayfa başına veri sonucu
page (isteğe bağlı) İstenen geçerli sayfa
curl --location --request GET 'https://tiklagit.ac/api/pixels?limit=2&page=1' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \

Sunucu yanıtı

{
    "error": "0",
    "data": {
        "result": 2,
        "perpage": 2,
        "currentpage": 1,
        "nextpage": 1,
        "maxpage": 1,
        "pixels": [
            {
                "id": 1,
                "type": "gtmpixel",
                "name": "GTM Pixel",
                "tag": "GA-123456789",
                "date": "2020-11-10 18:00:00"
            },
            {
                "id": 2,
                "type": "twitterpixel",
                "name": "Twitter Pixel",
                "tag": "1234567",
                "date": "2020-11-10 18:10:00"
            }
        ]
    }
}

Piksel Oluştur

POST https://tiklagit.ac/api/pixel/add

Bu uç nokta kullanılarak bir piksel oluşturulabilir. Piksel türünü ve etiketi göndermeniz gerekir.

Parametre Açıklama
type (required) gtmpixel | gapixel | fbpixel | adwordspixel | linkedinpixel | twitterpixel | adrollpixel | quorapixel | pinterest | bing | snapchat | reddit | tiktok
name (zorunlu) Pikseliniz için özel ad
tag (zorunlu) Piksel etiketi
curl --location --request POST 'https://tiklagit.ac/api/pixel/add' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \
--data-raw '{
    "type": "gtmpixel",
    "name": "My GTM",
    "tag": "GTM-ABCDE"
}'

Sunucu yanıtı

{
    "error": 0,
    "id": 1
}

Pikseli Güncelle

PUT https://tiklagit.ac/api/pixel/:id/update

Bir pikseli güncellemek için PUT isteğiyle JSON biçiminde geçerli veri göndermeniz gerekir. Veriler, aşağıda gösterildiği gibi isteğinizin ham gövdesi olarak gönderilmelidir. Aşağıdaki örnek gönderebileceğiniz tüm parametreleri gösterir ancak hepsini göndermeniz zorunlu değildir (Daha fazla bilgi için tabloya bakın).

Parametre Açıklama
name (isteğe bağlı) Pikseliniz için özel ad
tag (zorunlu) Piksel etiketi
curl --location --request PUT 'https://tiklagit.ac/api/pixel/:id/update' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \
--data-raw '{
    "name": "My GTM",
    "tag": "GTM-ABCDE"
}'

Sunucu yanıtı

{
    "error": 0,
    "message": "Pixel has been updated successfully."
}

Pikseli Sil

DELETE https://tiklagit.ac/api/pixel/:id/delete

Bir pikseli silmek için DELETE isteği göndermeniz gerekir.

curl --location --request DELETE 'https://tiklagit.ac/api/pixel/:id/delete' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \

Sunucu yanıtı

{
    "error": 0,
    "message": "Pixel has been deleted successfully."
}

QR Kodlar

QR Kodları Listele

GET https://tiklagit.ac/api/qr?limit=2&page=1

QR kodlarınızı API üzerinden almak için bu uç noktayı kullanabilirsiniz. Verileri filtreleyebilirsiniz de (Daha fazla bilgi için tabloya bakın).

Parametre Açıklama
limit (isteğe bağlı) Sayfa başına veri sonucu
page (isteğe bağlı) İstenen geçerli sayfa
curl --location --request GET 'https://tiklagit.ac/api/qr?limit=2&page=1' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \

Sunucu yanıtı

{
    "error": "0",
    "data": {
        "result": 2,
        "perpage": 2,
        "currentpage": 1,
        "nextpage": 1,
        "maxpage": 1,
        "qrs": [
            {
                "id": 2,
                "link": "https:\/\/tiklagit.ac\/qr\/a2d5e",
                "scans": 0,
                "name": "Google",
                "date": "2020-11-10 18:01:43"
            },
            {
                "id": 1,
                "link": "https:\/\/tiklagit.ac\/qr\/b9edfe",
                "scans": 5,
                "name": "Google Canada",
                "date": "2020-11-10 18:00:25"
            }
        ]
    }
}

Tek bir QR kodu getir

GET https://tiklagit.ac/api/qr/:id

Tek bir QR kodun ayrıntılarını API üzerinden almak için bu uç noktayı kullanabilirsiniz.

curl --location --request GET 'https://tiklagit.ac/api/qr/:id' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \

Sunucu yanıtı

{
    "error": 0,
    "details": {
        "id": 1,
        "link": "https:\/\/tiklagit.ac\/qr\/b9edfe",
        "scans": 5,
        "name": "Google Canada",
        "date": "2020-11-10 18:00:25"
    },
    "data": {
        "clicks": 1,
        "uniqueClicks": 1,
        "topCountries": {
            "Unknown": "1"
        },
        "topReferrers": {
            "Direct, email and other": "1"
        },
        "topBrowsers": {
            "Chrome": "1"
        },
        "topOs": {
            "Windows 10": "1"
        },
        "socialCount": {
            "facebook": 0,
            "twitter": 0,
            "instagram": 0
        }
    }
}

QR Kod Oluştur

POST https://tiklagit.ac/api/qr/add

Bir QR kod oluşturmak için POST isteğiyle JSON biçiminde geçerli veri göndermeniz gerekir. Veriler, aşağıda gösterildiği gibi isteğinizin ham gövdesi olarak gönderilmelidir. Aşağıdaki örnek gönderebileceğiniz tüm parametreleri gösterir ancak hepsini göndermeniz zorunlu değildir (Daha fazla bilgi için tabloya bakın).

Parametre Açıklama
type (zorunlu) text | vcard | link | email | phone | sms | wifi
data (zorunlu) QR kodun içine gömülecek veri. Veri, türe bağlı olarak metin (string) veya dizi (array) olabilir
background (isteğe bağlı) RGB renk, ör. rgb(255,255,255)
foreground (isteğe bağlı) RGB renk, ör. rgb(0,0,0)
logo (isteğe bağlı) Logonun yolu, png veya jpg
name (isteğe bağlı) QR kod adı
curl --location --request POST 'https://tiklagit.ac/api/qr/add' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \
--data-raw '{
    "type": "link",
    "data": "https:\/\/google.com",
    "background": "rgb(255,255,255)",
    "foreground": "rgb(0,0,0)",
    "logo": "https:\/\/site.com\/logo.png",
    "name": "QR Code API"
}'

Sunucu yanıtı

{
    "error": 0,
    "id": 3,
    "link": "https:\/\/tiklagit.ac\/qr\/a58f79"
}

QR Kodu Güncelle

PUT https://tiklagit.ac/api/qr/:id/update

Bir QR kodu güncellemek için PUT isteğiyle JSON biçiminde geçerli veri göndermeniz gerekir. Veriler, aşağıda gösterildiği gibi isteğinizin ham gövdesi olarak gönderilmelidir. Aşağıdaki örnek gönderebileceğiniz tüm parametreleri gösterir ancak hepsini göndermeniz zorunlu değildir (Daha fazla bilgi için tabloya bakın).

Parametre Açıklama
data (zorunlu) QR kodun içine gömülecek veri. Veri, türe bağlı olarak metin (string) veya dizi (array) olabilir
background (isteğe bağlı) RGB renk, ör. rgb(255,255,255)
foreground (isteğe bağlı) RGB renk, ör. rgb(0,0,0)
logo (isteğe bağlı) Logonun yolu, png veya jpg
curl --location --request PUT 'https://tiklagit.ac/api/qr/:id/update' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \
--data-raw '{
    "type": "link",
    "data": "https:\/\/google.com",
    "background": "rgb(255,255,255)",
    "foreground": "rgb(0,0,0)",
    "logo": "https:\/\/site.com\/logo.png"
}'

Sunucu yanıtı

{
    "error": 0,
    "message": "QR has been updated successfully."
}

QR Kodu Sil

DELETE https://tiklagit.ac/api/qr/:id/delete

Bir QR kodu silmek için DELETE isteği göndermeniz gerekir.

curl --location --request DELETE 'https://tiklagit.ac/api/qr/:id/delete' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \

Sunucu yanıtı

{
    "error": 0,
    "message": "QR Code has been deleted successfully."
}

Özel Geçiş Sayfası

Özel Geçiş Sayfalarını Listele

GET https://tiklagit.ac/api/splash?limit=2&page=1

Geçiş sayfalarını API üzerinden almak için bu uç noktayı kullanabilirsiniz. Ayrıca verileri filtreleyebilirsiniz (Daha fazla bilgi için tabloya bakın).

Parametre Açıklama
limit (isteğe bağlı) Sayfa başına veri sonucu
page (isteğe bağlı) İstenen geçerli sayfa
curl --location --request GET 'https://tiklagit.ac/api/splash?limit=2&page=1' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \

Sunucu yanıtı

{
    "error": "0",
    "data": {
        "result": 2,
        "perpage": 2,
        "currentpage": 1,
        "nextpage": 1,
        "maxpage": 1,
        "splash": [
            {
                "id": 1,
                "name": "Product 1 Promo",
                "date": "2020-11-10 18:00:00"
            },
            {
                "id": 2,
                "name": "Product 2 Promo",
                "date": "2020-11-10 18:10:00"
            }
        ]
    }
}